<cds-checkbox-group {{ widget.group_attrs|safe }}>
{% for group_name, group_choices, group_index in widget.optgroups %}{% for option in group_choices %}{% include option.template_name with widget=option %}{% endfor %}{% endfor %}</cds-checkbox-group>