<cds-checkbox name="{{ widget.name }}" value="{{ widget.value }}"{% if widget.attrs.id %} id="{{ widget.attrs.id }}"{% endif %} label-text="{{ widget.label }}"{% if widget.selected %} checked{% endif %}></cds-checkbox>